@@ -9,7 +9,11 @@ class DetaModel(BaseModel):
     key: Optional[str] = None
 
     _project_key: Optional[str] = None
-    __base_name__: str = ''
+
+    def __init_subclass__(cls, db_name: Optional[str] = None):
+        super(DetaModel, cls).__init_subclass__()
+        if not hasattr(cls, '__base_name__'):
+            cls.__base_name__ = db_name
 
     @classmethod
     def set_project_key(cls, project_key: str):
@@ -169,3 +173,10 @@ class DetaModel(BaseModel):
             for key, value in data.items():
                 if hasattr(self, key):
                     setattr(self, key, value)
+
+
+class DetaTimestampModel(DetaModel):
+    created_at: int = Field(
+        default_factory=lambda: int(datetime.utcnow().timestamp()),
+        alias='createdAt',
+    )
